use std::fs;

use anyhow::Result;
use serde::{Deserialize, Serialize};
use serde_json::{from_str, to_string, to_string_pretty};

#[derive(Clone, PartialEq, Eq, Deserialize, Serialize, Debug)]
pub struct Devices {
    pub plugs: Vec<String>,
}

impl Devices {
    pub async fn read(file: &str) -> Result<Self> {
        Ok(from_str(&fs::read_to_string(file)?)?)
    }

    pub fn to_json(&self) -> Result<String> {
        Ok(to_string(self)?)
    }

    #[allow(unused)]
    pub fn save(&self, file: &str) -> Result<()> {
        fs::write(file, to_string_pretty(self)?)?;

        Ok(())
    }
}

#[derive(Debug, Clone, Deserialize, Serialize, Default)]
pub struct DevicesWithName {
    pub plugs: Vec<(String, String)>,
}

impl DevicesWithName {
    pub fn to_json(&self) -> Result<String> {
        Ok(to_string(self)?)
    }
}

#[cfg(test)]
mod test {
    use super::Devices;
    use anyhow::Result;

    #[test]
    fn create_conf() -> Result<()> {
        let devices = Devices {
            plugs: vec!["Dev1".to_string(), "Dev2".to_string()],
        };

        devices.save("test_devices.conf")
    }
}
